@@ -24,34 +24,22 @@
 #include <string.h>
 #include <pk-backend.h>
 
-/**
- * pk_backend_get_description:
- */
 const gchar *
 pk_backend_get_description (PkBackend *backend)
 {
 	return g_strdup ("Test-Succeed");
 }
 
-/**
- * pk_backend_initialize:
- */
 void
 pk_backend_initialize (GKeyFile *conf, PkBackend *backend)
 {
 }
 
-/**
- * pk_backend_destroy:
- */
 void
 pk_backend_destroy (PkBackend *backend)
 {
 }
 
-/**
- * pk_backend_get_groups:
- */
 PkBitfield
 pk_backend_get_groups (PkBackend *backend)
 {
@@ -62,9 +50,6 @@ pk_backend_get_groups (PkBackend *backend)
 		-1);
 }
 
-/**
- * pk_backend_get_filters:
- */
 PkBitfield
 pk_backend_get_filters (PkBackend *backend)
 {
@@ -76,9 +61,6 @@ pk_backend_get_filters (PkBackend *backend)
 		-1);
 }
 
-/**
- * pk_backend_get_mime_types:
- */
 gchar **
 pk_backend_get_mime_types (PkBackend *backend)
 {
@@ -86,126 +68,84 @@ pk_backend_get_mime_types (PkBackend *backend)
 	return g_strdupv ((gchar **) mime_types);
 }
 
-/**
- * pk_backend_cancel:
- */
 void
 pk_backend_cancel (PkBackend *backend, PkBackendJob *job)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_download_packages:
- */
 void
 pk_backend_download_packages (PkBackend *backend, PkBackendJob *job, gchar **package_ids, const gchar *directory)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_categories:
- */
 void
 pk_backend_get_categories (PkBackend *backend, PkBackendJob *job)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_depends_on:
- */
 void
 pk_backend_depends_on (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_details:
- */
 void
 pk_backend_get_details (PkBackend *backend, PkBackendJob *job, gchar **package_ids)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_details_local:
- */
 void
 pk_backend_get_details_local (PkBackend *backend, PkBackendJob *job, gchar **files)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_files_local:
- */
 void
 pk_backend_get_files_local (PkBackend *backend, PkBackendJob *job, gchar **files)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_distro_upgrades:
- */
 void
 pk_backend_get_distro_upgrades (PkBackend *backend, PkBackendJob *job)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_files:
- */
 void
 pk_backend_get_files (PkBackend *backend, PkBackendJob *job, gchar **package_ids)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_required_by:
- */
 void
 pk_backend_required_by (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_update_detail:
- */
 void
 pk_backend_get_update_detail (PkBackend *backend, PkBackendJob *job, gchar **package_ids)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_updates:
- */
 void
 pk_backend_get_updates (PkBackend *backend, PkBackendJob *job, PkBitfield filters)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_install_packages:
- */
 void
 pk_backend_install_packages (PkBackend *backend, PkBackendJob *job, PkBitfield transaction_flags, gchar **package_ids)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_install_signature:
- */
 void
 pk_backend_install_signature (PkBackend *backend, PkBackendJob *job, PkSigTypeEnum type,
 			   const gchar *key_id, const gchar *package_id)
@@ -213,27 +153,18 @@ pk_backend_install_signature (PkBackend *backend, PkBackendJob *job, PkSigTypeEn
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_install_files:
- */
 void
 pk_backend_install_files (PkBackend *backend, PkBackendJob *job, PkBitfield transaction_flags, gchar **full_paths)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_refresh_cache:
- */
 void
 pk_backend_refresh_cache (PkBackend *backend, PkBackendJob *job, gboolean force)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_remove_packages:
- */
 void
 pk_backend_remove_packages (PkBackend *backend, PkBackendJob *job,
 			    PkBitfield transaction_flags,
@@ -244,45 +175,30 @@ pk_backend_remove_packages (PkBackend *backend, PkBackendJob *job,
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_resolve:
- */
 void
 pk_backend_resolve (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_search_details:
- */
 void
 pk_backend_search_details (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_search_files:
- */
 void
 pk_backend_search_files (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_search_groups:
- */
 void
 pk_backend_search_groups (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_search_name_timeout:
- **/
 static gboolean
 pk_backend_search_name_timeout (gpointer data)
 {
@@ -291,11 +207,6 @@ pk_backend_search_name_timeout (gpointer data)
 	return FALSE;
 }
 
-/**
- * pk_backend_search_names:
- *
- * A really long wait........
- */
 void
 pk_backend_search_names (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
@@ -303,56 +214,44 @@ pk_backend_search_names (PkBackend *backend, PkBackendJob *job, PkBitfield filte
 	g_timeout_add (200, pk_backend_search_name_timeout, backend);
 }
 
-/**
- * pk_backend_update_packages:
- */
 void
 pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield transaction_flags, gchar **package_ids)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_repo_list:
- */
 void
 pk_backend_get_repo_list (PkBackend *backend, PkBackendJob *job, PkBitfield filters)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_repo_enable:
- */
 void
 pk_backend_repo_enable (PkBackend *backend, PkBackendJob *job, const gchar *rid, gboolean enabled)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_repo_set_data:
- */
 void
 pk_backend_repo_set_data (PkBackend *backend, PkBackendJob *job, const gchar *rid, const gchar *parameter, const gchar *value)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_what_provides:
- */
 void
 pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
 	pk_backend_job_finished (job);
 }
 
-/**
- * pk_backend_get_packages:
- */
 void
 pk_backend_get_packages (PkBackend *backend, PkBackendJob *job, PkBitfield filters)
 {
 	pk_backend_job_finished (job);
 }
+
+void
+pk_backend_upgrade_system (PkBackend *backend, PkBackendJob *job, PkBitfield transaction_flags, const gchar *distro_id, PkUpgradeKindEnum upgrade_kind)
+{
+	pk_backend_job_finished (job);
+}
